.. role:: hidden
    :class: hidden-section

gpytorch.priors
===================================

.. automodule:: gpytorch.priors
.. currentmodule:: gpytorch.priors


Prior
----------------

.. autoclass:: Prior
   :members:


Standard Priors
-----------------------------

:hidden:`GammaPrior`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: GammaPrior
   :members:

:hidden:`HalfCauchyPrior`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: HalfCauchyPrior
   :members:

:hidden:`LKJCovariancePrior`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: LKJCovariancePrior
   :members:

:hidden:`MultivariateNormalPrior`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: MultivariateNormalPrior
   :members:

:hidden:`NormalPrior`
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: NormalPrior
   :members:

:hidden:`SmoothedBoxPrior`
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: SmoothedBoxPrior
   :members:
